@@ -1,3 +1,4 @@
+# calculates total test score from unscored data and key of correct answers
 .score <- function(Data, key) {
   if (!is.matrix(key)) {
     key <- matrix(key)
@@ -14,19 +15,30 @@
   rowSums(X)
 }
 
+# generalized logistic regression function
 .gNLR <- function(x, g, a, b, c, d, aDif, bDif, cDif, dDif) {
   return((c + cDif * g) + ((d + dDif * g) - (c + cDif * g)) / (1 + exp(-(a + aDif * g) * (x - (b + bDif * g)))))
 }
+.gNLR.is <- function(x, g, b0, b1, b2, b3, c, d, cDif, dDif) {
+  return((c + cDif * g) + ((d + dDif * g) - (c + cDif * g)) / (1 + exp(-(b0 + b1 * x + b2 * g + b3 * x * g))))
+}
 
+# generalized logistic regression function without group variable
 .gNLR_group <- function(x, a, b, c, d) {
   return(c + (d - c) / (1 + exp(-(a * (x - b)))))
 }
 
-.delta.gNLR <- deriv(y ~ (c + cDif * g) + ((d + dDif * g) - (c + cDif * g)) / (1 + exp(-(a + aDif * g) * (x - (b + bDif * g)))),
+# delta method for generalized logistic regression function
+.delta.gNLR.irt <- deriv(y ~ (c + cDif * g) + ((d + dDif * g) - (c + cDif * g)) / (1 + exp(-(a + aDif * g) * (x - (b + bDif * g)))),
   namevec = c("a", "b", "c", "d", "aDif", "bDif", "cDif", "dDif"),
   function(x, g, a, b, c, d, aDif, bDif, cDif, dDif) {}
 )
+.delta.gNLR.is <- deriv(y ~ (c + cDif * g) + ((d + dDif * g) - (c + cDif * g)) / (1 + exp(-(b0 + b1 * x + b2 * g + b3 * x * g))),
+  namevec = c("b0", "b1", "b2", "b3", "c", "d", "cDif", "dDif"),
+  function(x, g, b0, b1, b2, b3, c, d, cDif, dDif) {}
+)
 
+# ggplot2 theme for plot
 .plot.theme <- function() {
   ggplot2::theme_bw() +
     ggplot2::theme(
@@ -37,6 +49,7 @@
     )
 }
 
+# ggplot2 theme for plot with legend
 .plot.theme.legend <- function() {
   ggplot2::theme(
     legend.box.just = "top",
@@ -51,8 +64,15 @@
   )
 }
 
+# check whether value is in specified vector
 .checkInterval <- function(x, vec) {
   ifelse(x >= vec[1] & x <= vec[2], x,
     ifelse(x > vec[2], vec[2], vec[1])
   )
 }
+
+# paste function which removes empty strings
+.MYpaste <- function(..., sep = "", collapse = NULL, recycle0 = FALSE) {
+  x <- lapply(Filter(\(x)any(nzchar(x)), list(...)), \(x)x[nzchar(x)])
+  do.call(paste, c(x, sep = sep, collapse = collapse, recycle0 = recycle0))
+}
